@@ -1,7 +1,7 @@
 // drumkv1_lv2.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
 #include "drumkv1_programs.h"
 #include "drumkv1_controls.h"
 
+
 #ifdef CONFIG_LV2_OLD_HEADERS
 #include "lv2/lv2plug.in/ns/ext/midi/midi.h"
 #include "lv2/lv2plug.in/ns/ext/time/time.h"
@@ -349,10 +350,10 @@ void drumkv1_lv2::connect_port ( uint32_t port, void *data )
 	case AudioOutR:
 		m_outs[1] = (float *) data;
 		break;
-	default:
-		drumkv1::setParamPort(drumkv1::ParamIndex(port - ParamBase), (float *) data);
+	default: {
+		drumkv1::setParamPort(paramFromPort(port), (float *) data);
 		break;
-	}
+	}}
 }
 
 
@@ -552,6 +553,28 @@ uint32_t drumkv1_lv2::urid_map ( const char *uri ) const
 }
 
 
+uint32_t drumkv1_lv2::portFromParam ( drumkv1::ParamIndex index )
+{
+	uint32_t port = uint32_t(drumkv1_lv2::ParamBase + index);
+#if 1//DRUMKV1_LV2_LEGACY_2
+	if (index >= drumkv1::NUM_ELEMENT_PARAMS)
+		port -= (drumkv1::NUM_ELEMENT_PARAMS - 1);
+#endif
+	return port;
+}
+
+
+drumkv1::ParamIndex drumkv1_lv2::paramFromPort ( uint32_t port )
+{
+	int index = (port - drumkv1_lv2::ParamBase);
+#if 1//DRUMKV1_LV2_LEGACY_2
+	if (index > drumkv1::GEN1_SAMPLE)
+		index += (drumkv1::NUM_ELEMENT_PARAMS - 1);
+#endif
+	return drumkv1::ParamIndex(index);
+}
+
+
 //-------------------------------------------------------------------------
 // drumkv1_lv2 - Instantiation and cleanup.
 //
@@ -1035,6 +1058,11 @@ bool drumkv1_lv2::patch_get ( LV2_URID key )
 
 bool drumkv1_lv2::port_event ( drumkv1::ParamIndex index )
 {
+#if 1//DRUMKV1_LV2_LEGACY_2
+	if (index > drumkv1::GEN1_SAMPLE &&
+		index < drumkv1::NUM_ELEMENT_PARAMS)
+		return false;
+#endif
 	lv2_atom_forge_frame_time(&m_forge, m_ndelta);
 
 	LV2_Atom_Forge_Frame obj_frame;
@@ -1044,7 +1072,7 @@ bool drumkv1_lv2::port_event ( drumkv1::ParamIndex index )
 	LV2_Atom_Forge_Frame tup_frame;
 	lv2_atom_forge_tuple(&m_forge, &tup_frame);
 
-	lv2_atom_forge_int(&m_forge, int32_t(ParamBase + index));
+	lv2_atom_forge_int(&m_forge, portFromParam(index));
 	lv2_atom_forge_float(&m_forge, drumkv1::paramValue(index));
 
 	lv2_atom_forge_pop(&m_forge, &tup_frame);
@@ -1067,9 +1095,15 @@ bool drumkv1_lv2::port_events ( uint32_t nparams )
 
 	for (uint32_t i = 0; i < nparams; ++i) {
 		drumkv1::ParamIndex index = drumkv1::ParamIndex(i);
+	#if 0//DRUMKV1_LV2_LEGACY_2
 		if (index == drumkv1::GEN1_SAMPLE)
 			continue;
-		lv2_atom_forge_int(&m_forge, int32_t(ParamBase + index));
+	#else
+		if (index > drumkv1::GEN1_SAMPLE &&
+			index < drumkv1::NUM_ELEMENT_PARAMS)
+			continue;
+	#endif
+		lv2_atom_forge_int(&m_forge, portFromParam(index));
 		lv2_atom_forge_float(&m_forge, drumkv1::paramValue(index));
 	}
 
@@ -1093,9 +1127,14 @@ bool drumkv1_lv2::port_change_request ( drumkv1::ParamIndex index )
 	if (m_port_change_request->request_change == nullptr)
 		return false;
 
+#if 1//DRUMKV1_LV2_LEGACY_2
+	if (index > drumkv1::GEN1_SAMPLE &&
+		index < drumkv1::NUM_ELEMENT_PARAMS)
+		return false;
+#endif
 	return m_port_change_request->request_change(
 		m_port_change_request->handle,
-		uint32_t(ParamBase + index),
+		portFromParam(index),
 		drumkv1::paramValue(index))
 		== LV2_CONTROL_INPUT_PORT_CHANGE_SUCCESS;
 }
@@ -1112,9 +1151,17 @@ bool drumkv1_lv2::port_change_requests (void)
 
 	for (uint32_t i = 0; i < drumkv1::NUM_PARAMS; ++i) {
 		drumkv1::ParamIndex index = drumkv1::ParamIndex(i);
+	#if 0//DRUMKV1_LV2_LEGACY_2
+		if (index == drumkv1::GEN1_SAMPLE)
+			continue;
+	#else
+		if (index > drumkv1::GEN1_SAMPLE &&
+			index < drumkv1::NUM_ELEMENT_PARAMS)
+			continue;
+	#endif
 		m_port_change_request->request_change(
 			m_port_change_request->handle,
-			uint32_t(ParamBase + index),
+			portFromParam(index),
 			drumkv1::paramValue(index));
 	}
 
