@@ -1,7 +1,7 @@
 // drumkv1_lv2.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -94,6 +94,9 @@ public:
 	bool worker_work(const void *data, uint32_t size);
 	bool worker_response(const void *data, uint32_t size);
 
+	static uint32_t portFromParam(drumkv1::ParamIndex index);
+	static drumkv1::ParamIndex paramFromPort(uint32_t port);
+
 	static void qapp_instantiate();
 	static void qapp_cleanup();
 
