@@ -1,7 +1,7 @@
 // drumkv1_sched.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -85,6 +85,10 @@ public:
 		drumkv1 *m_pDrumk;
 	};
 
+	// process/clear pending schedules, immediately. (static)
+	static void sync_pending();
+	static void sync_reset();
+
 private:
 
 	// instance variables.
