@@ -1,7 +1,7 @@
 // drumkv1widget.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -987,7 +987,8 @@ void drumkv1widget::updateParamValues ( uint32_t nparams )
 			continue;
 		const float fValue = pDrumkUi->paramValue(index);
 		setParamValue(index, fValue, true);
-		updateParam(index, fValue);
+		if (i >= drumkv1::NUM_ELEMENT_PARAMS)
+			updateParam(index, fValue);
 		m_params_ab[i] = fValue;
 	}
 
@@ -1010,7 +1011,8 @@ void drumkv1widget::resetParamValues ( uint32_t nparams )
 			continue;
 		const float fValue = drumkv1_param::paramDefaultValue(index);
 		setParamValue(index, fValue, true);
-		updateParam(index, fValue);
+		if (i >= drumkv1::NUM_ELEMENT_PARAMS)
+			updateParam(index, fValue);
 		m_params_ab[i] = fValue;
 	}
 
@@ -1453,7 +1455,7 @@ void drumkv1widget::updateElement (void)
 				pParam->setDefaultValue(element->paramValue(index, 0));
 				pParam->setValue(fValue);
 			}
-			updateParam(index, fValue);
+		//	updateParam(index, fValue);
 			updateParamEx(index, fValue, true);
 			m_params_ab[i] = fValue;
 		}
@@ -1590,8 +1592,10 @@ void drumkv1widget::updateOffset ( drumkv1_sample *pSample, bool bDirty )
 		m_ui.Gen1Sample->setOffsetStart(iOffsetStart);
 		m_ui.Gen1Sample->setOffsetEnd(iOffsetEnd);
 		m_ui.Gen1Sample->setOffset(bOffset);
+	#if 0//DRUMKV1_LV2_LEGACY_2
 		updateParam(drumkv1::GEN1_OFFSET_1, float(iOffsetStart) / float(nframes));
 		updateParam(drumkv1::GEN1_OFFSET_2, float(iOffsetEnd) / float(nframes));
+	#endif
 		if (bDirty) {
 			QString sMessage;
 			if (bOffset) {
