@@ -23,6 +23,7 @@
 #define __drumkv1widget_env_h
 
 #include <QFrame>
+#include <QPolygon>
 
 
 //----------------------------------------------------------------------------
@@ -66,6 +67,15 @@ protected:
 	// Draw canvas.
 	void paintEvent(QPaintEvent *);
 
+	// Parameter node indexes.
+	enum NodeIndex {
+		Idle   = 1,
+		Attack = 2,
+		Decay1 = 3,
+		Decay2 = 4,
+		End    = 5
+	};
+
 	// Draw rectangular point.
 	QRect nodeRect(int iNode) const;
 	int nodeIndex(const QPoint& pos) const;
@@ -77,6 +87,12 @@ protected:
 	void mouseMoveEvent(QMouseEvent *pMouseEvent);
 	void mouseReleaseEvent(QMouseEvent *pMouseEvent);
 
+	// Resize canvas.
+	void resizeEvent(QResizeEvent *);
+
+	// Update the drawing polygon.
+	void updatePolygon();
+
 private:
 
 	// Instance state.
