@@ -1,7 +1,7 @@
 // drumkv1widget_lv2.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -212,8 +212,9 @@ void drumkv1widget_lv2::port_event ( uint32_t port_index,
 {
 	if (format == 0 && buffer_size == sizeof(float)) {
 		const drumkv1::ParamIndex index
-			= drumkv1::ParamIndex(port_index - drumkv1_lv2::ParamBase);
+			= drumkv1_lv2::paramFromPort(port_index);
 		const float fValue = *(float *) buffer;
+	#if 0//DRUMKV1_LV2_LEGACY_2
 		if (index < drumkv1::NUM_ELEMENT_PARAMS && m_iShowEvent > 0) {
 			drumkv1_ui *pDrumkUi = ui_instance();
 			if (pDrumkUi) {
@@ -224,7 +225,11 @@ void drumkv1widget_lv2::port_event ( uint32_t port_index,
 			}
 		}
 		if (index >= drumkv1::NUM_ELEMENT_PARAMS || m_iShowEvent > 0)
-			setParamValue(index, fValue);
+	#else
+		if (index == drumkv1::GEN1_SAMPLE ||
+			index >= drumkv1::NUM_ELEMENT_PARAMS || m_iShowEvent > 0)
+	#endif
+		setParamValue(index, fValue);
 	}
 }
 
@@ -233,6 +238,20 @@ void drumkv1widget_lv2::port_event ( uint32_t port_index,
 void drumkv1widget_lv2::updateParam (
 	drumkv1::ParamIndex index, float fValue ) const
 {
+	if (index == drumkv1::GEN1_SAMPLE)
+		return;
+
+#if 0//DRUMKV1_LV2_LEGACY_2
+	if (index == drumkv1::GEN1_OFFSET_1 ||
+		index == drumkv1::GEN1_OFFSET_2) {
+#else
+	if (index < drumkv1::NUM_ELEMENT_PARAMS) {
+#endif
+		m_pDrumkUi->setParamValue(index, fValue);
+		m_pDrumkUi->updateParam(index);
+		return;
+	}
+
 	m_pDrumkUi->write_function(index, fValue);
 }
 
