@@ -1,7 +1,7 @@
 // drumkv1widget_programs.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -39,7 +39,7 @@ class drumkv1widget_programs : public QTreeWidget
 public:
 
 	// ctor.
-	drumkv1widget_programs(QWidget *pParent = 0);
+	drumkv1widget_programs(QWidget *pParent = nullptr);
 	// dtor.
 	~drumkv1widget_programs();
 
@@ -47,7 +47,7 @@ public:
 	void loadPrograms(drumkv1_programs *pPrograms);
 	void savePrograms(drumkv1_programs *pPrograms);
 
-	void selectProgram(drumkv1_programs *pPrograms);
+	QString currentProgramName() const;
 
 public slots:
 
